@@ -1,5 +1,7 @@
 ;;; gnus-vm.el --- vm interface for Gnus
-;; Copyright (C) 1994,95,96,97 Free Software Foundation, Inc.
+
+;; Copyright (C) 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001
+;;	Free Software Foundation, Inc.
 
 ;; Author: Per Persson <pp@gnu.ai.mit.edu>
 ;; Keywords: news, mail
@@ -36,6 +38,7 @@
 (require 'gnus-msg)
 
 (eval-when-compile
+  (require 'cl)
   (autoload 'vm-mode "vm")
   (autoload 'vm-save-message "vm")
   (autoload 'vm-forward-message "vm")
@@ -46,11 +49,10 @@
   "Inhibit loading `win-vm' if using a window-system.
 Has to be set before gnus-vm is loaded.")
 
-(or gnus-vm-inhibit-window-system
-    (condition-case nil
-	(when window-system
-	  (require 'win-vm))
-      (error nil)))
+(unless gnus-vm-inhibit-window-system
+  (ignore-errors
+    (when window-system
+      (require 'win-vm))))
 
 (when (not (featurep 'vm))
   (load "vm"))
@@ -82,30 +84,25 @@ If N is a negative number, save the N previous articles.
 If N is nil and any articles have been marked with the process mark,
 save those articles instead."
   (interactive "P")
+  (require 'gnus-art)
   (let ((gnus-default-article-saver 'gnus-summary-save-in-vm))
     (gnus-summary-save-article arg)))
 
 (defun gnus-summary-save-in-vm (&optional folder)
   (interactive)
-  (let ((default-name
-	  (funcall gnus-mail-save-name gnus-newsgroup-name
-		   gnus-current-headers gnus-newsgroup-last-mail)))
-    (setq folder
-	  (cond ((eq folder 'default) default-name)
-		(folder folder)
-		(t (gnus-read-save-file-name
-		    "Save %s in VM folder:" default-name))))
-    (gnus-make-directory (file-name-directory folder))
-    (set-buffer gnus-original-article-buffer)
+  (setq folder
+	(gnus-read-save-file-name
+	 "Save %s in VM folder:" folder
+	 gnus-mail-save-name gnus-newsgroup-name
+	 gnus-current-headers 'gnus-newsgroup-last-mail))
+  (gnus-eval-in-buffer-window gnus-original-article-buffer
     (save-excursion
       (save-restriction
 	(widen)
 	(let ((vm-folder (gnus-vm-make-folder)))
 	  (vm-save-message folder)
-	  (kill-buffer vm-folder))))
-    ;; Remember the directory name to save articles.
-    (setq gnus-newsgroup-last-mail folder)))
+	  (kill-buffer vm-folder))))))
 
 (provide 'gnus-vm)
 
-;;; gnus-vm.el ends here.
+;;; gnus-vm.el ends here
